import { v as UpdateProjectOrderInCollectionRequest$1, a as UpdateProjectOrderInCollectionResponse$1 } from './portfolio-projects-v1-project-in-collection-project-in-collections.universal-BeKxaG_D.js';

interface ProjectsInCollections {
    /**
     * Collection ID.
     * @format GUID
     */
    collectionId?: string;
    /** Project object. */
    project?: Project;
    /**
     * Index that determines the placement of a project within the collection.  <br />
     *
     * Default: [Epoch](https://www.epoch101.com/) timestamp. <br />
     */
    sortOrder?: number | null;
    /**
     * Project placement ID.
     * @readonly
     * @format GUID
     */
    id?: string | null;
}
interface Project extends ProjectCoverOneOf {
    /** Project cover image. */
    coverImage?: Image;
    /** Project cover video. */
    coverVideo?: Video;
    /**
     * Project ID.
     * @readonly
     * @format GUID
     */
    id?: string | null;
    /**
     * Revision number, which increments by 1 each time the project is updated. To prevent conflicting changes, the existing revision must be passed when updating the project object.
     * @readonly
     */
    revision?: string | null;
    /**
     * Project title.
     * @maxLength 100
     */
    title?: string | null;
    /** Project description. */
    description?: string | null;
    /** Whether the project is hidden from the portfolio. Default: `false` */
    hidden?: boolean | null;
    /**
     * IDs of the collections that include the project.
     * @format GUID
     * @maxSize 1000
     */
    collectionIds?: string[];
    /** Project details. */
    details?: ProjectDetail[];
    /** Project slug. */
    slug?: string | null;
    /**
     * Date and time the project was created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Date and time the project was updated.
     * @readonly
     */
    updatedDate?: Date | null;
    /**
     * Project page URL and relative path. Returned when `includePageUrl` is `true` in the request.
     * @readonly
     */
    url?: PageUrlV2;
    /** Project SEO data. */
    seoData?: SeoSchema;
}
/** @oneof */
interface ProjectCoverOneOf {
    /** Project cover image. */
    coverImage?: Image;
    /** Project cover video. */
    coverVideo?: Video;
}
interface Image {
    /** Information about the Wix Media image. */
    imageInfo?: CommonImage;
    /** Focal point of the image. */
    focalPoint?: Point;
}
interface CommonImage {
    /** WixMedia image ID. Required. */
    id?: string;
    /**
     * Image URL.
     * @readonly
     */
    url?: string;
    /** Original image height. Required. */
    height?: number;
    /** Original image width. Required. */
    width?: number;
    /** Image alt text. */
    altText?: string | null;
    /** Image filename. */
    filename?: string | null;
}
interface Point {
    /** X-coordinate of the focal point. */
    x?: number;
    /** Y-coordinate of the focal point. */
    y?: number;
}
interface Video {
    /** Information about the Wix Media video. */
    videoInfo?: VideoV2;
    /** Manually defined Video duration in milliseconds. */
    durationInMillis?: number | null;
}
interface VideoV2 {
    /** WixMedia ID. Required. */
    id?: string;
    /** Video URL. */
    url?: string;
    /**
     * Available resolutions for the video, starting with the optimal resolution.
     * @maxSize 100
     */
    resolutions?: VideoResolution[];
    /** Video filename. */
    filename?: string | null;
    /** Video posters. */
    posters?: CommonImage[];
}
interface VideoResolution {
    /** Video URL.  Required. */
    url?: string;
    /** Video height. Required. */
    height?: number;
    /** Video width.  Required. */
    width?: number;
    /** Video format for example, mp4, hls.  Required. */
    format?: string;
    /** Video quality for example 480p, 720p. */
    quality?: string | null;
    /** Video filename. */
    filename?: string | null;
}
/**
 * Project label.
 * One of:
 * + `text`
 * + `link`
 */
interface ProjectDetail extends ProjectDetailValueOneOf {
    /** Project label in plain text format. */
    text?: string;
    /** Project label in link format. */
    link?: DetailsLink;
    /** Project label. */
    label?: string;
}
/** @oneof */
interface ProjectDetailValueOneOf {
    /** Project label in plain text format. */
    text?: string;
    /** Project label in link format. */
    link?: DetailsLink;
}
interface DetailsLink {
    /** Display text of the link. */
    text?: string | null;
    /**
     * Target URL of the link.
     * @format WEB_URL
     */
    url?: string | null;
    /**
     * Whether the link opens in a new tab or window. One of:
     * * `'_blank'`: The link opens in a new tab or window.
     * * `'_self'`: The link opens in the same tab or window.
     */
    target?: string | null;
}
interface PageUrlV2 {
    /** The relative path for the page within the site. For example, `/product-page/a-product`. */
    relativePath?: string;
    /** The page's full URL. For example, `https://mysite.com/product-page/a-product`. */
    url?: string | null;
}
/**
 * The SEO schema object contains data about different types of meta tags. It makes sure that the information about your page is presented properly to search engines.
 * The search engines use this information for ranking purposes, or to display snippets in the search results.
 * This data will override other sources of tags (for example patterns) and will be included in the <head> section of the HTML document, while not being displayed on the page itself.
 */
interface SeoSchema {
    /** SEO tag information. */
    tags?: Tag[];
    /** SEO general settings. */
    settings?: Settings;
}
interface Keyword {
    /** Keyword value. */
    term?: string;
    /** Whether the keyword is the main focus keyword. */
    isMain?: boolean;
    /**
     * The source that added the keyword terms to the SEO settings.
     * @maxLength 1000
     */
    origin?: string | null;
}
interface Tag {
    /**
     * SEO tag type.
     *
     *
     * Supported values: `title`, `meta`, `script`, `link`.
     */
    type?: string;
    /**
     * A `{"key": "value"}` pair object where each SEO tag property (`"name"`, `"content"`, `"rel"`, `"href"`) contains a value.
     * For example: `{"name": "description", "content": "the description itself"}`.
     */
    props?: Record<string, any> | null;
    /** SEO tag meta data. For example, `{"height": 300, "width": 240}`. */
    meta?: Record<string, any> | null;
    /** SEO tag inner content. For example, `<title> inner content </title>`. */
    children?: string;
    /** Whether the tag is a custom tag. */
    custom?: boolean;
    /** Whether the tag is disabled. */
    disabled?: boolean;
}
interface Settings {
    /**
     * Whether the Auto Redirect feature, which creates `301 redirects` on a slug change, is enabled.
     *
     *
     * Default: `false` (Auto Redirect is enabled.)
     */
    preventAutoRedirect?: boolean;
    /**
     * User-selected keyword terms for a specific page.
     * @maxSize 5
     */
    keywords?: Keyword[];
}
interface UpdateProjectOrderInCollectionRequest {
    /**
     * ID of the project to update.
     * @format GUID
     */
    projectId: string;
    /**
     * Collection ID.
     * @format GUID
     */
    collectionId: string;
    /** Index that determines the placement of a project within the collection. */
    sortOrder: number | null;
}
interface UpdateProjectOrderInCollectionResponse {
    /** Updated project placement within the specified collection. */
    projectInCollection?: ProjectsInCollections;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function updateProjectOrderInCollection(): __PublicMethodMetaInfo<'PATCH', {
    projectId: string;
    collectionId: string;
}, UpdateProjectOrderInCollectionRequest$1, UpdateProjectOrderInCollectionRequest, UpdateProjectOrderInCollectionResponse$1, UpdateProjectOrderInCollectionResponse>;

export { type __PublicMethodMetaInfo, updateProjectOrderInCollection };
